@@ -82,3 +82,29 @@ class TestSubscription(BaseTestCase):
 
         response = Subscription.enable(code="SUB_vsyqdmlzble3uii", token="d7gofp6yppn3qz7")
         self.assertEqual(response['status'], True)
+
+    @httpretty.activate
+    def test_generate_update_subscription_link(self):
+        """Function defined to test generation of a link for updating the card on a subscription"""
+        httpretty.register_uri(
+            httpretty.GET,
+            self.endpoint_url("/subscription/SUB_vsyqdmlzble3uii/manage/link"),
+            content_type='text/json',
+            status=200,
+        )
+
+        response = Subscription.generate_update_subscription_link(subscription_code='SUB_vsyqdmlzble3uii')
+        self.assertEqual(response['status'], True)
+        
+    @httpretty.activate
+    def test_send_update_subscription_link(self):
+        """Function defined to test emailing a customer a link for updating the card on their subscription"""
+        httpretty.register_uri(
+            httpretty.POST,
+            self.endpoint_url("/subscription/SUB_vsyqdmlzble3uii/manage/email"),
+            content_type='text/json',
+            status=200,
+        )
+
+        response = Subscription.send_update_subscription_link(subscription_code='SUB_vsyqdmlzble3uii')
+        self.assertEqual(response['status'], True)
\ No newline at end of file
