@@ -70,17 +70,24 @@ class Transaction(PayStackBase):
         return cls().requests.get(f"transaction/{transaction_id}")
 
     @classmethod
-    def list(cls):
+    def list(cls, **kwargs):
         """
         List transactions.
 
         Args:
             No argument required.
+            optional:
+                customer: When used as a param, returns the transactions related to the customer
+                status: Filter transactions by status ('failed', 'success', 'abandoned')
+                perPage: Specify how many records you want to retrieve per page.
+                    If not specify we use a default value of 50. (Integer)
+                page: Specify exactly what page you want to retrieve.
+                    If not specify we use a default value of 1. (Integer)
 
         Returns:
             Json data from paystack API.
         """
-        return cls().requests.get('transaction')
+        return cls().requests.get('transaction', qs=kwargs,)
 
     @classmethod
     def totals(cls):
